==> nezha-compute-common-1.25.0-20180727.042847-2-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/OrientInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

public class OrientInfo {

    Long advertId;
    Long orientId;
    boolean isManagered; //是否为托管配置
    Integer chargeType;  //计费方式
    Long target = 0l;       //目标成本
    Long fee = 0l; //出价
    Double cvr;
    Double confidence;   //置信度
    Double bias;         //偏差

    public OrientInfo() {
    }

    public OrientInfo(Long advertId, Long orientId, boolean isManagered, Integer chargeType, Long target, Long fee, Double cvr, Double confidence, Double bias) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.isManagered = isManagered;
        this.chargeType = chargeType;
        this.target = target;
        this.fee = fee;
        this.cvr = cvr;
        this.confidence = confidence;
        this.bias = bias;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public boolean isManagered() {
        return isManagered;
    }

    public void setManagered(boolean managered) {
        isManagered = managered;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getTarget() {
        return target;
    }

    public void setTarget(Long target) {
        this.target = target;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Double getConfidence() {
        return confidence;
    }

    public void setConfidence(Double confidence) {
        this.confidence = confidence;
    }

    public Double getBias() {
        return bias;
    }

    public void setBias(Double bias) {
        this.bias = bias;
    }
}

==> nezha-compute-common-1.25.9-20180816.063340-1-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/OrientInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

public class OrientInfo {

    Long advertId;
    Long orientId;
    boolean isManagered; //是否为托管配置
    Integer chargeType;  //计费方式
    Long target = 0l;       //目标成本
    Long fee = 0l; //出价
    Double cvr;
    Double confidence;   //置信度
    Double bias;         //偏差
    Double orientCostG1d = 0.0;             //配置消耗
    Double orientClkG1d=0.0;               //配置点击
    Double orientCvrG1d=0.0;               //配置cvr


    public OrientInfo() {
    }

    public OrientInfo(Long advertId, Long orientId, boolean isManagered, Integer chargeType, Long target, Long fee, Double cvr, Double confidence, Double bias, Double orientCostG1d, Double orientClkG1d, Double orientCvrG1d) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.isManagered = isManagered;
        this.chargeType = chargeType;
        this.target = target;
        this.fee = fee;
        this.cvr = cvr;
        this.confidence = confidence;
        this.bias = bias;
        this.orientCostG1d = orientCostG1d;
        this.orientClkG1d = orientClkG1d;
        this.orientCvrG1d = orientCvrG1d;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public boolean isManagered() {
        return isManagered;
    }

    public void setManagered(boolean managered) {
        isManagered = managered;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getTarget() {
        return target;
    }

    public void setTarget(Long target) {
        this.target = target;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Double getConfidence() {
        return confidence;
    }

    public void setConfidence(Double confidence) {
        this.confidence = confidence;
    }

    public Double getBias() {
        return bias;
    }

    public void setBias(Double bias) {
        this.bias = bias;
    }

    public Double getOrientCostG1d() {
        return orientCostG1d;
    }

    public void setOrientCostG1d(Double orientCostG1d) {
        this.orientCostG1d = orientCostG1d;
    }

    public Double getOrientClkG1d() {
        return orientClkG1d;
    }

    public void setOrientClkG1d(Double orientClkG1d) {
        this.orientClkG1d = orientClkG1d;
    }

    public Double getOrientCvrG1d() {
        return orientCvrG1d;
    }

    public void setOrientCvrG1d(Double orientCvrG1d) {
        this.orientCvrG1d = orientCvrG1d;
    }
}
